#! /bin/sh

echo Installing UNC90 GPIO kernel driver
insmod /lib/modules/2.6.12.5-fs.1-LxNETES3.2/kernel/drivers/char/unc90_gpio.ko

echo Installing Xilinx IO driver
insmod /lib/modules/2.6.12.5-fs.1-LxNETES3.2/extra/xilinx.ko

echo Programming EK FPGA
loadfpga /usr/echopro.bin 

echo Turning on USB power
poke 1 69

# Assumes either only ET2 or ET3, not a combination of both
# Also assumes membrane keypad
ET_MODE=`peek 56 | grep data | cut -b 8-9`
case $ET_MODE in
	'11')	echo "ET3 detected"
			ET_TYPE="/usr/ET3-PCB-01.bin";;
	*)		echo "ET2 detected"
			ET_TYPE="/usr/et-adj-gain.bin";;
esac

echo Programming ET channel A FPGA
loadet $ET_TYPE 48

echo Programming ET channel C FPGA
loadet $ET_TYPE 96

FIR=`grep "FIR_filter" /Config/echopro.ini | cut -b 12-`
echo FIR filter is $FIR

# This is the adc sample rate without filtering/decimation
# ie, the rate that datacapture sees
RATE=`grep "adc sample rate" /Config/echopro.ini | cut -b 17-`
echo Sample rate is $RATE
case $RATE in
	2.5)	SPS=3;;
	10)	SPS=35;;
	25)	SPS=67;;
	50)	SPS=99;;
	100)	SPS=130;;
	250)	SPS=146
			FIR=2 ;;
	500)	SPS=146;;
	1000)	SPS=161;;
	2000)	SPS=176;;
	*)	SPS=35;;
esac

# If FIR != 0, we need to modify the sample rate to allow for decimation
if [ $FIR = 1 ] ; then
	case $RATE in
		2)	SPS=35;;
		5)	SPS=67;;
		10)	SPS=99;;
		20)	SPS=130;;
		100)	SPS=146;;
		200)	SPS=161;;
		*)	SPS=130;;
	esac
fi

echo SPS is $SPS


CHA=`grep "gain_a" /Config/echopro.ini | cut -b 8-`
echo Channel A gain is $CHA
case $CHA in
	1)	GAIN_A=0;;
	2)	GAIN_A=1;;
	4)	GAIN_A=2;;
	8)	GAIN_A=3;;
	16)	GAIN_A=4;;
	32)	GAIN_A=5;;
	64)	GAIN_A=6;;
	*)	GAIN_A=0;;
esac

# ET3 is hardcoded to an internal gain of 1 (0 for the ADC)
if [ $ET_MODE = 11 ] ; then
	GAIN_A=0
fi
echo GAIN_A is $GAIN_A

CHB=`grep "gain_b" /Config/echopro.ini | cut -b 8-`
echo Channel B gain is $CHB
case $CHB in
	1)	GAIN_B=0;;
	2)	GAIN_B=1;;
	4)	GAIN_B=2;;
	8)	GAIN_B=3;;
	16)	GAIN_B=4;;
	32)	GAIN_B=5;;
	64)	GAIN_B=6;;
	*)	GAIN_B=0;;
esac
echo GAIN_B is $GAIN_B

CHC=`grep "gain_c" /Config/echopro.ini | cut -b 8-`
echo Channel C gain is $CHC
case $CHC in
	1)	GAIN_C=0;;
	2)	GAIN_C=1;;
	4)	GAIN_C=2;;
	8)	GAIN_C=3;;
	16)	GAIN_C=4;;
	32)	GAIN_C=5;;
	64)	GAIN_C=6;;
	*)	GAIN_C=0;;
esac
echo GAIN_C is $GAIN_C

CHD=`grep "gain_d" /Config/echopro.ini | cut -b 8-`
echo Channel D gain is $CHD
case $CHD in
	1)	GAIN_D=0;;
	2)	GAIN_D=1;;
	4)	GAIN_D=2;;
	8)	GAIN_D=3;;
	16)	GAIN_D=4;;
	32)	GAIN_D=5;;
	64)	GAIN_D=6;;
	*)	GAIN_D=0;;
esac
echo GAIN_D is $GAIN_D


# Start ET software - this sets WR low, sets the channel, sets the sample rate,
# sets the start flag, sets WR high, and turns the bus around from write to read
poke 11 48
poke 1 128
poke 3 80
poke $SPS 60
poke $GAIN_A 61
poke $GAIN_B 62
poke $FIR 63
poke 1 10
poke 15 48

# Do the same thing, but for the second ET
poke 11 96
poke 3 128
poke 3 80
poke $SPS 60
poke $GAIN_C 61
poke $GAIN_D 62
poke $FIR 63
poke 1 10
poke 15 96

# reset the modem
poke 0 51

echo Setting I2C hub to EK channel and enabling modem
poke 1 3

#sleep 1

#ifconfig eth0 172.16.5.121
echo Running network script
/usr/bin/network.sh


echo Mounting USB memory
/usr/bin/usb_mount &
sleep 1
ln -s /media/usb /SeismicData
mkdir /KelunjiData/Logs
mkdir /SeismicData/Logs

if [ -f /media/usb/factorydefaults ] ; then
	echo "Restoring factory defaults"
	cp /Config/echopro.ini.factory /Config/echopro.ini
	rm /media/usb/factorydefaults
fi

echo Starting GPS daemon
/usr/bin/gpsd -o 1 &

# allow time for GPS daemon to set the date
sleep 2	

# needed by ppp subsystem
mkdir /var/lock


# Note - this is only exported for those programs started in this script.
# Once the interactive user shell is started, this will not be valid.
echo Setting timezone
export TZ=`cat /usr/utc_offset.dat`
echo New localtime is:
date

echo Loading I2C ADC driver
insmod /lib/modules/2.6.12.5-fs.1-LxNETES3.2/extra/ad7417.ko


echo Starting datacapture
datacapture &
#sleep 2

echo Turning on LCD...
poke 15 66
sleep 4

echo Starting keypad handler

MODE=`peek 56 | grep data | cut -b 8-9`
case $MODE in
	'7 ')	echo "Storm keypad detected"
		CMD="/usr/bin/keypad -s";;
	*)	echo "Using default keypad"
		CMD="/usr/bin/keypad" ;;
esac
echo $CMD
$CMD &

# sleep here so the datacapture pid is available for the lcd
# otherwise wrapper kills it, and lcd says sampling is off
sleep 2

echo Starting datacapture wrapper
/usr/bin/wrapper &

echo Starting web server
/usr/bin/thttpd -C /www/config

echo Starting ftp file sender
/usr/bin/ftp-latest > /dev/null &

echo Starting SOH daemon
/usr/bin/soh &

echo Starting alarm daemon
/usr/bin/alarms &

echo Starting clean up process
/usr/bin/delete_old &

echo Starting FTP daemon
/usr/bin/vsftpd

echo Suppressing kernel messages
echo "4 4 1 7" > /proc/sys/kernel/printk

echo Setting hostname
if [ -f /etc/DR4050 ] ; then
	echo "DR4050" > /proc/sys/kernel/hostname
else
	echo "EchoPro" > /proc/sys/kernel/hostname
fi

echo Starting watchdog
mknod /dev/watchdog c 10 130
/usr/bin/watchdog &

